# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetCatalogResult',
    'AwaitableGetCatalogResult',
    'get_catalog',
    'get_catalog_output',
]

@pulumi.output_type
class GetCatalogResult:
    """
    A collection of values returned by getCatalog.
    """
    def __init__(__self__, annotations=None, branch=None, cluster_id=None, description=None, id=None, kind=None, labels=None, name=None, password=None, project_id=None, scope=None, url=None, username=None, version=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        pulumi.set(__self__, "annotations", annotations)
        if branch and not isinstance(branch, str):
            raise TypeError("Expected argument 'branch' to be a str")
        pulumi.set(__self__, "branch", branch)
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        pulumi.set(__self__, "kind", kind)
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        pulumi.set(__self__, "labels", labels)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if scope and not isinstance(scope, str):
            raise TypeError("Expected argument 'scope' to be a str")
        pulumi.set(__self__, "scope", scope)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def annotations(self) -> Mapping[str, str]:
        """
        (Computed) Annotations for the catalog (map)
        """
        return pulumi.get(self, "annotations")

    @property
    @pulumi.getter
    def branch(self) -> str:
        """
        (Computed) The branch of the catalog repo to use (string)
        """
        return pulumi.get(self, "branch")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> str:
        """
        (Computed) The cluster id of the catalog (string)
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        (Computed) A catalog description (string)
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def kind(self) -> str:
        """
        (Computed) The kind of the catalog. Just helm by the moment (string)
        """
        return pulumi.get(self, "kind")

    @property
    @pulumi.getter
    def labels(self) -> Mapping[str, str]:
        """
        (Computed) Labels for the catalog (map)
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def password(self) -> str:
        """
        (Computed/Sensitive) The password to access the catalog if needed (string)
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        """
        (Computed) The project id of the catalog (string)
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def scope(self) -> Optional[str]:
        return pulumi.get(self, "scope")

    @property
    @pulumi.getter
    def url(self) -> str:
        """
        (Computed) The url of the catalog repo (string)
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def username(self) -> str:
        """
        (Computed/Sensitive) The username to access the catalog if needed (string)
        """
        return pulumi.get(self, "username")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        (Computed) Helm version for the catalog (string)
        """
        return pulumi.get(self, "version")


class AwaitableGetCatalogResult(GetCatalogResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCatalogResult(
            annotations=self.annotations,
            branch=self.branch,
            cluster_id=self.cluster_id,
            description=self.description,
            id=self.id,
            kind=self.kind,
            labels=self.labels,
            name=self.name,
            password=self.password,
            project_id=self.project_id,
            scope=self.scope,
            url=self.url,
            username=self.username,
            version=self.version)


def get_catalog(name: Optional[str] = None,
                scope: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCatalogResult:
    """
    Use this data source to retrieve information about a Rancher v2 catalog.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_rancher2 as rancher2

    library = rancher2.get_catalog(name="catalog")
    ```


    :param str name: The catalog name.
    :param str scope: The scope of the catalog. `cluster`, `global`, and `project` are supported. Default `global` (string)
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['scope'] = scope
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('rancher2:index/getCatalog:getCatalog', __args__, opts=opts, typ=GetCatalogResult).value

    return AwaitableGetCatalogResult(
        annotations=pulumi.get(__ret__, 'annotations'),
        branch=pulumi.get(__ret__, 'branch'),
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        kind=pulumi.get(__ret__, 'kind'),
        labels=pulumi.get(__ret__, 'labels'),
        name=pulumi.get(__ret__, 'name'),
        password=pulumi.get(__ret__, 'password'),
        project_id=pulumi.get(__ret__, 'project_id'),
        scope=pulumi.get(__ret__, 'scope'),
        url=pulumi.get(__ret__, 'url'),
        username=pulumi.get(__ret__, 'username'),
        version=pulumi.get(__ret__, 'version'))
def get_catalog_output(name: Optional[pulumi.Input[str]] = None,
                       scope: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCatalogResult]:
    """
    Use this data source to retrieve information about a Rancher v2 catalog.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_rancher2 as rancher2

    library = rancher2.get_catalog(name="catalog")
    ```


    :param str name: The catalog name.
    :param str scope: The scope of the catalog. `cluster`, `global`, and `project` are supported. Default `global` (string)
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['scope'] = scope
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('rancher2:index/getCatalog:getCatalog', __args__, opts=opts, typ=GetCatalogResult)
    return __ret__.apply(lambda __response__: GetCatalogResult(
        annotations=pulumi.get(__response__, 'annotations'),
        branch=pulumi.get(__response__, 'branch'),
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        kind=pulumi.get(__response__, 'kind'),
        labels=pulumi.get(__response__, 'labels'),
        name=pulumi.get(__response__, 'name'),
        password=pulumi.get(__response__, 'password'),
        project_id=pulumi.get(__response__, 'project_id'),
        scope=pulumi.get(__response__, 'scope'),
        url=pulumi.get(__response__, 'url'),
        username=pulumi.get(__response__, 'username'),
        version=pulumi.get(__response__, 'version')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 password: pulumi.Input[str],
                 username: pulumi.Input[str],
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 must_change_password: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[str] password: The user password (string)
        :param pulumi.Input[str] username: The user username (string)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations for global role binding (map)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Labels for global role binding (map)
        :param pulumi.Input[bool] must_change_password: The user must change password at first login (bool)
        :param pulumi.Input[str] name: The user full name (string)
        """
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "username", username)
        if annotations is not None:
            pulumi.set(__self__, "annotations", annotations)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if must_change_password is not None:
            pulumi.set(__self__, "must_change_password", must_change_password)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[str]:
        """
        The user password (string)
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def username(self) -> pulumi.Input[str]:
        """
        The user username (string)
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: pulumi.Input[str]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter
    def annotations(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Annotations for global role binding (map)
        """
        return pulumi.get(self, "annotations")

    @annotations.setter
    def annotations(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "annotations", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Labels for global role binding (map)
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter(name="mustChangePassword")
    def must_change_password(self) -> Optional[pulumi.Input[bool]]:
        """
        The user must change password at first login (bool)
        """
        return pulumi.get(self, "must_change_password")

    @must_change_password.setter
    def must_change_password(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "must_change_password", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The user full name (string)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 must_change_password: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 principal_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations for global role binding (map)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Labels for global role binding (map)
        :param pulumi.Input[bool] must_change_password: The user must change password at first login (bool)
        :param pulumi.Input[str] name: The user full name (string)
        :param pulumi.Input[str] password: The user password (string)
        :param pulumi.Input[Sequence[pulumi.Input[str]]] principal_ids: (Computed) The user principal IDs (list)
        :param pulumi.Input[str] username: The user username (string)
        """
        if annotations is not None:
            pulumi.set(__self__, "annotations", annotations)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if must_change_password is not None:
            pulumi.set(__self__, "must_change_password", must_change_password)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if principal_ids is not None:
            pulumi.set(__self__, "principal_ids", principal_ids)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def annotations(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Annotations for global role binding (map)
        """
        return pulumi.get(self, "annotations")

    @annotations.setter
    def annotations(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "annotations", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Labels for global role binding (map)
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter(name="mustChangePassword")
    def must_change_password(self) -> Optional[pulumi.Input[bool]]:
        """
        The user must change password at first login (bool)
        """
        return pulumi.get(self, "must_change_password")

    @must_change_password.setter
    def must_change_password(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "must_change_password", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The user full name (string)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The user password (string)
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="principalIds")
    def principal_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        (Computed) The user principal IDs (list)
        """
        return pulumi.get(self, "principal_ids")

    @principal_ids.setter
    def principal_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "principal_ids", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        The user username (string)
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 must_change_password: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Rancher v2 User resource. This can be used to create Users for Rancher v2 environments and retrieve their information.

        When a Rancher User is created, it doesn't have a global role binding. At least, `user-base` global role binding in needed in order to enable user login.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_rancher2 as rancher2

        # Create a new rancher2 User
        foo = rancher2.User("foo",
            name="Foo user",
            username="foo",
            password="changeme",
            enabled=True,
            must_change_password=True)
        # Create a new rancher2 global_role_binding for User
        foo_global_role_binding = rancher2.GlobalRoleBinding("foo",
            name="foo",
            global_role_id="user-base",
            user_id=foo.id)
        ```

        ## Import

        Users can be imported using the Rancher User ID

        ```sh
        $ pulumi import rancher2:index/user:User foo &lt;user_id&gt;
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations for global role binding (map)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Labels for global role binding (map)
        :param pulumi.Input[bool] must_change_password: The user must change password at first login (bool)
        :param pulumi.Input[str] name: The user full name (string)
        :param pulumi.Input[str] password: The user password (string)
        :param pulumi.Input[str] username: The user username (string)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Rancher v2 User resource. This can be used to create Users for Rancher v2 environments and retrieve their information.

        When a Rancher User is created, it doesn't have a global role binding. At least, `user-base` global role binding in needed in order to enable user login.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_rancher2 as rancher2

        # Create a new rancher2 User
        foo = rancher2.User("foo",
            name="Foo user",
            username="foo",
            password="changeme",
            enabled=True,
            must_change_password=True)
        # Create a new rancher2 global_role_binding for User
        foo_global_role_binding = rancher2.GlobalRoleBinding("foo",
            name="foo",
            global_role_id="user-base",
            user_id=foo.id)
        ```

        ## Import

        Users can be imported using the Rancher User ID

        ```sh
        $ pulumi import rancher2:index/user:User foo &lt;user_id&gt;
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 must_change_password: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            __props__.__dict__["annotations"] = annotations
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["labels"] = labels
            __props__.__dict__["must_change_password"] = must_change_password
            __props__.__dict__["name"] = name
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            if username is None and not opts.urn:
                raise TypeError("Missing required property 'username'")
            __props__.__dict__["username"] = username
            __props__.__dict__["principal_ids"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(User, __self__).__init__(
            'rancher2:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            enabled: Optional[pulumi.Input[bool]] = None,
            labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            must_change_password: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[str]] = None,
            principal_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            username: Optional[pulumi.Input[str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations for global role binding (map)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Labels for global role binding (map)
        :param pulumi.Input[bool] must_change_password: The user must change password at first login (bool)
        :param pulumi.Input[str] name: The user full name (string)
        :param pulumi.Input[str] password: The user password (string)
        :param pulumi.Input[Sequence[pulumi.Input[str]]] principal_ids: (Computed) The user principal IDs (list)
        :param pulumi.Input[str] username: The user username (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["annotations"] = annotations
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["labels"] = labels
        __props__.__dict__["must_change_password"] = must_change_password
        __props__.__dict__["name"] = name
        __props__.__dict__["password"] = password
        __props__.__dict__["principal_ids"] = principal_ids
        __props__.__dict__["username"] = username
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def annotations(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Annotations for global role binding (map)
        """
        return pulumi.get(self, "annotations")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Labels for global role binding (map)
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter(name="mustChangePassword")
    def must_change_password(self) -> pulumi.Output[Optional[bool]]:
        """
        The user must change password at first login (bool)
        """
        return pulumi.get(self, "must_change_password")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The user full name (string)
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[str]:
        """
        The user password (string)
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="principalIds")
    def principal_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        (Computed) The user principal IDs (list)
        """
        return pulumi.get(self, "principal_ids")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[str]:
        """
        The user username (string)
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GlobalRoleArgs', 'GlobalRole']

@pulumi.input_type
class GlobalRoleArgs:
    def __init__(__self__, *,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 inherited_cluster_roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 new_user_default: Optional[pulumi.Input[bool]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['GlobalRoleRuleArgs']]]] = None):
        """
        The set of arguments for constructing a GlobalRole resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations for global role object (map)
        :param pulumi.Input[str] description: Global role description (string)
        :param pulumi.Input[Sequence[pulumi.Input[str]]] inherited_cluster_roles: Names of role templates whose permissions are granted by this global role in every cluster besides the local cluster (list)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Labels for global role object (map)
        :param pulumi.Input[str] name: Global role name (string)
        :param pulumi.Input[bool] new_user_default: Whether or not this role should be added to new users. Default `false` (bool)
        :param pulumi.Input[Sequence[pulumi.Input['GlobalRoleRuleArgs']]] rules: Global role policy rules (list)
        """
        if annotations is not None:
            pulumi.set(__self__, "annotations", annotations)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if inherited_cluster_roles is not None:
            pulumi.set(__self__, "inherited_cluster_roles", inherited_cluster_roles)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if new_user_default is not None:
            pulumi.set(__self__, "new_user_default", new_user_default)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def annotations(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Annotations for global role object (map)
        """
        return pulumi.get(self, "annotations")

    @annotations.setter
    def annotations(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "annotations", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Global role description (string)
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="inheritedClusterRoles")
    def inherited_cluster_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Names of role templates whose permissions are granted by this global role in every cluster besides the local cluster (list)
        """
        return pulumi.get(self, "inherited_cluster_roles")

    @inherited_cluster_roles.setter
    def inherited_cluster_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "inherited_cluster_roles", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Labels for global role object (map)
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Global role name (string)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="newUserDefault")
    def new_user_default(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether or not this role should be added to new users. Default `false` (bool)
        """
        return pulumi.get(self, "new_user_default")

    @new_user_default.setter
    def new_user_default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "new_user_default", value)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GlobalRoleRuleArgs']]]]:
        """
        Global role policy rules (list)
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GlobalRoleRuleArgs']]]]):
        pulumi.set(self, "rules", value)


@pulumi.input_type
class _GlobalRoleState:
    def __init__(__self__, *,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 builtin: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 inherited_cluster_roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 new_user_default: Optional[pulumi.Input[bool]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['GlobalRoleRuleArgs']]]] = None):
        """
        Input properties used for looking up and filtering GlobalRole resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations for global role object (map)
        :param pulumi.Input[bool] builtin: (Computed) Builtin global role (bool)
        :param pulumi.Input[str] description: Global role description (string)
        :param pulumi.Input[Sequence[pulumi.Input[str]]] inherited_cluster_roles: Names of role templates whose permissions are granted by this global role in every cluster besides the local cluster (list)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Labels for global role object (map)
        :param pulumi.Input[str] name: Global role name (string)
        :param pulumi.Input[bool] new_user_default: Whether or not this role should be added to new users. Default `false` (bool)
        :param pulumi.Input[Sequence[pulumi.Input['GlobalRoleRuleArgs']]] rules: Global role policy rules (list)
        """
        if annotations is not None:
            pulumi.set(__self__, "annotations", annotations)
        if builtin is not None:
            pulumi.set(__self__, "builtin", builtin)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if inherited_cluster_roles is not None:
            pulumi.set(__self__, "inherited_cluster_roles", inherited_cluster_roles)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if new_user_default is not None:
            pulumi.set(__self__, "new_user_default", new_user_default)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def annotations(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Annotations for global role object (map)
        """
        return pulumi.get(self, "annotations")

    @annotations.setter
    def annotations(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "annotations", value)

    @property
    @pulumi.getter
    def builtin(self) -> Optional[pulumi.Input[bool]]:
        """
        (Computed) Builtin global role (bool)
        """
        return pulumi.get(self, "builtin")

    @builtin.setter
    def builtin(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "builtin", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Global role description (string)
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="inheritedClusterRoles")
    def inherited_cluster_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Names of role templates whose permissions are granted by this global role in every cluster besides the local cluster (list)
        """
        return pulumi.get(self, "inherited_cluster_roles")

    @inherited_cluster_roles.setter
    def inherited_cluster_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "inherited_cluster_roles", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Labels for global role object (map)
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Global role name (string)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="newUserDefault")
    def new_user_default(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether or not this role should be added to new users. Default `false` (bool)
        """
        return pulumi.get(self, "new_user_default")

    @new_user_default.setter
    def new_user_default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "new_user_default", value)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GlobalRoleRuleArgs']]]]:
        """
        Global role policy rules (list)
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GlobalRoleRuleArgs']]]]):
        pulumi.set(self, "rules", value)


class GlobalRole(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 inherited_cluster_roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 new_user_default: Optional[pulumi.Input[bool]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GlobalRoleRuleArgs', 'GlobalRoleRuleArgsDict']]]]] = None,
                 __props__=None):
        """
        Provides a Rancher v2 Global Role resource. This can be used to create Global Role for Rancher v2 and retrieve their information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_rancher2 as rancher2

        # Create a new rancher2 Global Role
        foo = rancher2.GlobalRole("foo",
            name="foo",
            new_user_default=True,
            description="Terraform global role acceptance test",
            rules=[{
                "api_groups": ["*"],
                "resources": ["secrets"],
                "verbs": ["create"],
            }])
        ```

        ## Import

        Global Role can be imported using the Rancher Global Role ID

        ```sh
        $ pulumi import rancher2:index/globalRole:GlobalRole foo &lt;global_role_id&gt;
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations for global role object (map)
        :param pulumi.Input[str] description: Global role description (string)
        :param pulumi.Input[Sequence[pulumi.Input[str]]] inherited_cluster_roles: Names of role templates whose permissions are granted by this global role in every cluster besides the local cluster (list)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Labels for global role object (map)
        :param pulumi.Input[str] name: Global role name (string)
        :param pulumi.Input[bool] new_user_default: Whether or not this role should be added to new users. Default `false` (bool)
        :param pulumi.Input[Sequence[pulumi.Input[Union['GlobalRoleRuleArgs', 'GlobalRoleRuleArgsDict']]]] rules: Global role policy rules (list)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[GlobalRoleArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Rancher v2 Global Role resource. This can be used to create Global Role for Rancher v2 and retrieve their information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_rancher2 as rancher2

        # Create a new rancher2 Global Role
        foo = rancher2.GlobalRole("foo",
            name="foo",
            new_user_default=True,
            description="Terraform global role acceptance test",
            rules=[{
                "api_groups": ["*"],
                "resources": ["secrets"],
                "verbs": ["create"],
            }])
        ```

        ## Import

        Global Role can be imported using the Rancher Global Role ID

        ```sh
        $ pulumi import rancher2:index/globalRole:GlobalRole foo &lt;global_role_id&gt;
        ```

        :param str resource_name: The name of the resource.
        :param GlobalRoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GlobalRoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 inherited_cluster_roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 new_user_default: Optional[pulumi.Input[bool]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GlobalRoleRuleArgs', 'GlobalRoleRuleArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GlobalRoleArgs.__new__(GlobalRoleArgs)

            __props__.__dict__["annotations"] = annotations
            __props__.__dict__["description"] = description
            __props__.__dict__["inherited_cluster_roles"] = inherited_cluster_roles
            __props__.__dict__["labels"] = labels
            __props__.__dict__["name"] = name
            __props__.__dict__["new_user_default"] = new_user_default
            __props__.__dict__["rules"] = rules
            __props__.__dict__["builtin"] = None
        super(GlobalRole, __self__).__init__(
            'rancher2:index/globalRole:GlobalRole',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            builtin: Optional[pulumi.Input[bool]] = None,
            description: Optional[pulumi.Input[str]] = None,
            inherited_cluster_roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            new_user_default: Optional[pulumi.Input[bool]] = None,
            rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GlobalRoleRuleArgs', 'GlobalRoleRuleArgsDict']]]]] = None) -> 'GlobalRole':
        """
        Get an existing GlobalRole resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations for global role object (map)
        :param pulumi.Input[bool] builtin: (Computed) Builtin global role (bool)
        :param pulumi.Input[str] description: Global role description (string)
        :param pulumi.Input[Sequence[pulumi.Input[str]]] inherited_cluster_roles: Names of role templates whose permissions are granted by this global role in every cluster besides the local cluster (list)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Labels for global role object (map)
        :param pulumi.Input[str] name: Global role name (string)
        :param pulumi.Input[bool] new_user_default: Whether or not this role should be added to new users. Default `false` (bool)
        :param pulumi.Input[Sequence[pulumi.Input[Union['GlobalRoleRuleArgs', 'GlobalRoleRuleArgsDict']]]] rules: Global role policy rules (list)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GlobalRoleState.__new__(_GlobalRoleState)

        __props__.__dict__["annotations"] = annotations
        __props__.__dict__["builtin"] = builtin
        __props__.__dict__["description"] = description
        __props__.__dict__["inherited_cluster_roles"] = inherited_cluster_roles
        __props__.__dict__["labels"] = labels
        __props__.__dict__["name"] = name
        __props__.__dict__["new_user_default"] = new_user_default
        __props__.__dict__["rules"] = rules
        return GlobalRole(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def annotations(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Annotations for global role object (map)
        """
        return pulumi.get(self, "annotations")

    @property
    @pulumi.getter
    def builtin(self) -> pulumi.Output[bool]:
        """
        (Computed) Builtin global role (bool)
        """
        return pulumi.get(self, "builtin")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Global role description (string)
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="inheritedClusterRoles")
    def inherited_cluster_roles(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Names of role templates whose permissions are granted by this global role in every cluster besides the local cluster (list)
        """
        return pulumi.get(self, "inherited_cluster_roles")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Labels for global role object (map)
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Global role name (string)
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="newUserDefault")
    def new_user_default(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether or not this role should be added to new users. Default `false` (bool)
        """
        return pulumi.get(self, "new_user_default")

    @property
    @pulumi.getter
    def rules(self) -> pulumi.Output[Sequence['outputs.GlobalRoleRule']]:
        """
        Global role policy rules (list)
        """
        return pulumi.get(self, "rules")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .app import *
from .app_v2 import *
from .auth_config_active_directory import *
from .auth_config_adfs import *
from .auth_config_azure_ad import *
from .auth_config_free_ipa import *
from .auth_config_github import *
from .auth_config_keycloak import *
from .auth_config_okta import *
from .auth_config_open_ldap import *
from .auth_config_ping import *
from .bootstrap import *
from .catalog import *
from .catalog_v2 import *
from .certificate import *
from .cloud_credential import *
from .cluster import *
from .cluster_driver import *
from .cluster_role_template_binding import *
from .cluster_sync import *
from .cluster_template import *
from .cluster_v2 import *
from .config_map_v2 import *
from .custom_user_token import *
from .etcd_backup import *
from .feature import *
from .get_app import *
from .get_catalog import *
from .get_catalog_v2 import *
from .get_certificate import *
from .get_cloud_credential import *
from .get_cluster import *
from .get_cluster_driver import *
from .get_cluster_role_template_binding import *
from .get_cluster_template import *
from .get_cluster_v2 import *
from .get_config_map_v2 import *
from .get_etcd_backup import *
from .get_global_role import *
from .get_global_role_binding import *
from .get_multi_cluster_app import *
from .get_namespace import *
from .get_node_driver import *
from .get_node_pool import *
from .get_node_template import *
from .get_pod_security_admission_configuration_template import *
from .get_principal import *
from .get_project import *
from .get_project_role_template_binding import *
from .get_registry import *
from .get_role_template import *
from .get_secret import *
from .get_secret_v2 import *
from .get_setting import *
from .get_storage_class_v2 import *
from .get_user import *
from .global_role import *
from .global_role_binding import *
from .machine_config_v2 import *
from .multi_cluster_app import *
from .namespace import *
from .node_driver import *
from .node_pool import *
from .node_template import *
from .pod_security_admission_configuration_template import *
from .project import *
from .project_role_template_binding import *
from .provider import *
from .registry import *
from .role_template import *
from .secret import *
from .secret_v2 import *
from .setting import *
from .storage_class_v2 import *
from .token import *
from .user import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_rancher2.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_rancher2.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "rancher2",
  "mod": "index/app",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/app:App": "App"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/appV2",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/appV2:AppV2": "AppV2"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/authConfigActiveDirectory",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/authConfigActiveDirectory:AuthConfigActiveDirectory": "AuthConfigActiveDirectory"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/authConfigAdfs",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/authConfigAdfs:AuthConfigAdfs": "AuthConfigAdfs"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/authConfigAzureAd",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/authConfigAzureAd:AuthConfigAzureAd": "AuthConfigAzureAd"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/authConfigFreeIpa",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/authConfigFreeIpa:AuthConfigFreeIpa": "AuthConfigFreeIpa"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/authConfigGithub",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/authConfigGithub:AuthConfigGithub": "AuthConfigGithub"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/authConfigKeycloak",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/authConfigKeycloak:AuthConfigKeycloak": "AuthConfigKeycloak"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/authConfigOkta",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/authConfigOkta:AuthConfigOkta": "AuthConfigOkta"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/authConfigOpenLdap",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/authConfigOpenLdap:AuthConfigOpenLdap": "AuthConfigOpenLdap"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/authConfigPing",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/authConfigPing:AuthConfigPing": "AuthConfigPing"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/bootstrap",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/bootstrap:Bootstrap": "Bootstrap"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/catalog",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/catalog:Catalog": "Catalog"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/catalogV2",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/catalogV2:CatalogV2": "CatalogV2"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/certificate",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/cloudCredential",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/cloudCredential:CloudCredential": "CloudCredential"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/cluster",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/clusterDriver",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/clusterDriver:ClusterDriver": "ClusterDriver"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/clusterRoleTemplateBinding",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/clusterRoleTemplateBinding:ClusterRoleTemplateBinding": "ClusterRoleTemplateBinding"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/clusterSync",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/clusterSync:ClusterSync": "ClusterSync"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/clusterTemplate",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/clusterTemplate:ClusterTemplate": "ClusterTemplate"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/clusterV2",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/clusterV2:ClusterV2": "ClusterV2"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/configMapV2",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/configMapV2:ConfigMapV2": "ConfigMapV2"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/customUserToken",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/customUserToken:CustomUserToken": "CustomUserToken"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/etcdBackup",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/etcdBackup:EtcdBackup": "EtcdBackup"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/feature",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/feature:Feature": "Feature"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/globalRole",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/globalRole:GlobalRole": "GlobalRole"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/globalRoleBinding",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/globalRoleBinding:GlobalRoleBinding": "GlobalRoleBinding"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/machineConfigV2",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/machineConfigV2:MachineConfigV2": "MachineConfigV2"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/multiClusterApp",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/multiClusterApp:MultiClusterApp": "MultiClusterApp"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/namespace",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/nodeDriver",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/nodeDriver:NodeDriver": "NodeDriver"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/nodePool",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/nodePool:NodePool": "NodePool"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/nodeTemplate",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/nodeTemplate:NodeTemplate": "NodeTemplate"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/podSecurityAdmissionConfigurationTemplate",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/podSecurityAdmissionConfigurationTemplate:PodSecurityAdmissionConfigurationTemplate": "PodSecurityAdmissionConfigurationTemplate"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/project",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/project:Project": "Project"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/projectRoleTemplateBinding",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/projectRoleTemplateBinding:ProjectRoleTemplateBinding": "ProjectRoleTemplateBinding"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/registry",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/registry:Registry": "Registry"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/roleTemplate",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/roleTemplate:RoleTemplate": "RoleTemplate"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/secret",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/secretV2",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/secretV2:SecretV2": "SecretV2"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/setting",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/setting:Setting": "Setting"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/storageClassV2",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/storageClassV2:StorageClassV2": "StorageClassV2"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/token",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/token:Token": "Token"
  }
 },
 {
  "pkg": "rancher2",
  "mod": "index/user",
  "fqn": "pulumi_rancher2",
  "classes": {
   "rancher2:index/user:User": "User"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "rancher2",
  "token": "pulumi:providers:rancher2",
  "fqn": "pulumi_rancher2",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetCatalogV2Result',
    'AwaitableGetCatalogV2Result',
    'get_catalog_v2',
    'get_catalog_v2_output',
]

@pulumi.output_type
class GetCatalogV2Result:
    """
    A collection of values returned by getCatalogV2.
    """
    def __init__(__self__, annotations=None, ca_bundle=None, cluster_id=None, enabled=None, exponential_backoff_max_retries=None, exponential_backoff_max_wait=None, exponential_backoff_min_wait=None, git_branch=None, git_repo=None, id=None, insecure=None, insecure_plain_http=None, labels=None, name=None, resource_version=None, secret_name=None, secret_namespace=None, service_account=None, service_account_namespace=None, url=None):
        if annotations and not isinstance(annotations, dict):
            raise TypeError("Expected argument 'annotations' to be a dict")
        pulumi.set(__self__, "annotations", annotations)
        if ca_bundle and not isinstance(ca_bundle, str):
            raise TypeError("Expected argument 'ca_bundle' to be a str")
        pulumi.set(__self__, "ca_bundle", ca_bundle)
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if exponential_backoff_max_retries and not isinstance(exponential_backoff_max_retries, int):
            raise TypeError("Expected argument 'exponential_backoff_max_retries' to be a int")
        pulumi.set(__self__, "exponential_backoff_max_retries", exponential_backoff_max_retries)
        if exponential_backoff_max_wait and not isinstance(exponential_backoff_max_wait, int):
            raise TypeError("Expected argument 'exponential_backoff_max_wait' to be a int")
        pulumi.set(__self__, "exponential_backoff_max_wait", exponential_backoff_max_wait)
        if exponential_backoff_min_wait and not isinstance(exponential_backoff_min_wait, int):
            raise TypeError("Expected argument 'exponential_backoff_min_wait' to be a int")
        pulumi.set(__self__, "exponential_backoff_min_wait", exponential_backoff_min_wait)
        if git_branch and not isinstance(git_branch, str):
            raise TypeError("Expected argument 'git_branch' to be a str")
        pulumi.set(__self__, "git_branch", git_branch)
        if git_repo and not isinstance(git_repo, str):
            raise TypeError("Expected argument 'git_repo' to be a str")
        pulumi.set(__self__, "git_repo", git_repo)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if insecure and not isinstance(insecure, bool):
            raise TypeError("Expected argument 'insecure' to be a bool")
        pulumi.set(__self__, "insecure", insecure)
        if insecure_plain_http and not isinstance(insecure_plain_http, bool):
            raise TypeError("Expected argument 'insecure_plain_http' to be a bool")
        pulumi.set(__self__, "insecure_plain_http", insecure_plain_http)
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        pulumi.set(__self__, "labels", labels)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if resource_version and not isinstance(resource_version, str):
            raise TypeError("Expected argument 'resource_version' to be a str")
        pulumi.set(__self__, "resource_version", resource_version)
        if secret_name and not isinstance(secret_name, str):
            raise TypeError("Expected argument 'secret_name' to be a str")
        pulumi.set(__self__, "secret_name", secret_name)
        if secret_namespace and not isinstance(secret_namespace, str):
            raise TypeError("Expected argument 'secret_namespace' to be a str")
        pulumi.set(__self__, "secret_namespace", secret_namespace)
        if service_account and not isinstance(service_account, str):
            raise TypeError("Expected argument 'service_account' to be a str")
        pulumi.set(__self__, "service_account", service_account)
        if service_account_namespace and not isinstance(service_account_namespace, str):
            raise TypeError("Expected argument 'service_account_namespace' to be a str")
        pulumi.set(__self__, "service_account_namespace", service_account_namespace)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter
    def annotations(self) -> Mapping[str, str]:
        """
        (Computed) Annotations for the catalog v2 (map)
        """
        return pulumi.get(self, "annotations")

    @property
    @pulumi.getter(name="caBundle")
    def ca_bundle(self) -> str:
        """
        (Computed) PEM encoded CA bundle which will be used to validate the repo's certificate (string)
        """
        return pulumi.get(self, "ca_bundle")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> str:
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def enabled(self) -> bool:
        """
        (Computed) If disabled the repo clone will not be updated or allowed to be installed from. Default: `true` (bool)
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="exponentialBackoffMaxRetries")
    def exponential_backoff_max_retries(self) -> int:
        return pulumi.get(self, "exponential_backoff_max_retries")

    @property
    @pulumi.getter(name="exponentialBackoffMaxWait")
    def exponential_backoff_max_wait(self) -> int:
        return pulumi.get(self, "exponential_backoff_max_wait")

    @property
    @pulumi.getter(name="exponentialBackoffMinWait")
    def exponential_backoff_min_wait(self) -> int:
        return pulumi.get(self, "exponential_backoff_min_wait")

    @property
    @pulumi.getter(name="gitBranch")
    def git_branch(self) -> str:
        """
        (Computed) Git Repository branch containing Helm chart definitions. Default `master` (string)
        """
        return pulumi.get(self, "git_branch")

    @property
    @pulumi.getter(name="gitRepo")
    def git_repo(self) -> str:
        """
        (Computed) The url of the catalog v2 repo (string)
        """
        return pulumi.get(self, "git_repo")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def insecure(self) -> bool:
        """
        (Computed) Use insecure HTTPS to download the repo's index. Default: `false` (bool)
        """
        return pulumi.get(self, "insecure")

    @property
    @pulumi.getter(name="insecurePlainHttp")
    def insecure_plain_http(self) -> Optional[bool]:
        return pulumi.get(self, "insecure_plain_http")

    @property
    @pulumi.getter
    def labels(self) -> Mapping[str, str]:
        """
        (Computed) Labels for the catalog v2 (map)
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceVersion")
    def resource_version(self) -> str:
        """
        (Computed) The k8s resource version (string)
        """
        return pulumi.get(self, "resource_version")

    @property
    @pulumi.getter(name="secretName")
    def secret_name(self) -> str:
        """
        (Computed) K8s secret name to be used to connect to the repo (string)
        """
        return pulumi.get(self, "secret_name")

    @property
    @pulumi.getter(name="secretNamespace")
    def secret_namespace(self) -> str:
        """
        (Computed) K8s secret namespace (string)
        """
        return pulumi.get(self, "secret_namespace")

    @property
    @pulumi.getter(name="serviceAccount")
    def service_account(self) -> str:
        """
        (Computed) K8s service account used to deploy charts instead of the end users credentials (string)
        """
        return pulumi.get(self, "service_account")

    @property
    @pulumi.getter(name="serviceAccountNamespace")
    def service_account_namespace(self) -> str:
        """
        (Computed) The username to access the catalog if needed (string)
        """
        return pulumi.get(self, "service_account_namespace")

    @property
    @pulumi.getter
    def url(self) -> str:
        """
        (Computed) URL to an index generated by Helm (string)
        """
        return pulumi.get(self, "url")


class AwaitableGetCatalogV2Result(GetCatalogV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCatalogV2Result(
            annotations=self.annotations,
            ca_bundle=self.ca_bundle,
            cluster_id=self.cluster_id,
            enabled=self.enabled,
            exponential_backoff_max_retries=self.exponential_backoff_max_retries,
            exponential_backoff_max_wait=self.exponential_backoff_max_wait,
            exponential_backoff_min_wait=self.exponential_backoff_min_wait,
            git_branch=self.git_branch,
            git_repo=self.git_repo,
            id=self.id,
            insecure=self.insecure,
            insecure_plain_http=self.insecure_plain_http,
            labels=self.labels,
            name=self.name,
            resource_version=self.resource_version,
            secret_name=self.secret_name,
            secret_namespace=self.secret_namespace,
            service_account=self.service_account,
            service_account_namespace=self.service_account_namespace,
            url=self.url)


def get_catalog_v2(cluster_id: Optional[str] = None,
                   exponential_backoff_max_retries: Optional[int] = None,
                   exponential_backoff_max_wait: Optional[int] = None,
                   exponential_backoff_min_wait: Optional[int] = None,
                   insecure_plain_http: Optional[bool] = None,
                   name: Optional[str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCatalogV2Result:
    """
    Use this data source to retrieve information about a Rancher2 catalog v2. Catalog v2 resource is available at Rancher v2.5.x and above.


    :param str cluster_id: The cluster id of the catalog V2 (string)
    :param str name: The name of the catalog v2 (string)
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['exponentialBackoffMaxRetries'] = exponential_backoff_max_retries
    __args__['exponentialBackoffMaxWait'] = exponential_backoff_max_wait
    __args__['exponentialBackoffMinWait'] = exponential_backoff_min_wait
    __args__['insecurePlainHttp'] = insecure_plain_http
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('rancher2:index/getCatalogV2:getCatalogV2', __args__, opts=opts, typ=GetCatalogV2Result).value

    return AwaitableGetCatalogV2Result(
        annotations=pulumi.get(__ret__, 'annotations'),
        ca_bundle=pulumi.get(__ret__, 'ca_bundle'),
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        enabled=pulumi.get(__ret__, 'enabled'),
        exponential_backoff_max_retries=pulumi.get(__ret__, 'exponential_backoff_max_retries'),
        exponential_backoff_max_wait=pulumi.get(__ret__, 'exponential_backoff_max_wait'),
        exponential_backoff_min_wait=pulumi.get(__ret__, 'exponential_backoff_min_wait'),
        git_branch=pulumi.get(__ret__, 'git_branch'),
        git_repo=pulumi.get(__ret__, 'git_repo'),
        id=pulumi.get(__ret__, 'id'),
        insecure=pulumi.get(__ret__, 'insecure'),
        insecure_plain_http=pulumi.get(__ret__, 'insecure_plain_http'),
        labels=pulumi.get(__ret__, 'labels'),
        name=pulumi.get(__ret__, 'name'),
        resource_version=pulumi.get(__ret__, 'resource_version'),
        secret_name=pulumi.get(__ret__, 'secret_name'),
        secret_namespace=pulumi.get(__ret__, 'secret_namespace'),
        service_account=pulumi.get(__ret__, 'service_account'),
        service_account_namespace=pulumi.get(__ret__, 'service_account_namespace'),
        url=pulumi.get(__ret__, 'url'))
def get_catalog_v2_output(cluster_id: Optional[pulumi.Input[str]] = None,
                          exponential_backoff_max_retries: Optional[pulumi.Input[Optional[int]]] = None,
                          exponential_backoff_max_wait: Optional[pulumi.Input[Optional[int]]] = None,
                          exponential_backoff_min_wait: Optional[pulumi.Input[Optional[int]]] = None,
                          insecure_plain_http: Optional[pulumi.Input[Optional[bool]]] = None,
                          name: Optional[pulumi.Input[str]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCatalogV2Result]:
    """
    Use this data source to retrieve information about a Rancher2 catalog v2. Catalog v2 resource is available at Rancher v2.5.x and above.


    :param str cluster_id: The cluster id of the catalog V2 (string)
    :param str name: The name of the catalog v2 (string)
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['exponentialBackoffMaxRetries'] = exponential_backoff_max_retries
    __args__['exponentialBackoffMaxWait'] = exponential_backoff_max_wait
    __args__['exponentialBackoffMinWait'] = exponential_backoff_min_wait
    __args__['insecurePlainHttp'] = insecure_plain_http
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('rancher2:index/getCatalogV2:getCatalogV2', __args__, opts=opts, typ=GetCatalogV2Result)
    return __ret__.apply(lambda __response__: GetCatalogV2Result(
        annotations=pulumi.get(__response__, 'annotations'),
        ca_bundle=pulumi.get(__response__, 'ca_bundle'),
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        enabled=pulumi.get(__response__, 'enabled'),
        exponential_backoff_max_retries=pulumi.get(__response__, 'exponential_backoff_max_retries'),
        exponential_backoff_max_wait=pulumi.get(__response__, 'exponential_backoff_max_wait'),
        exponential_backoff_min_wait=pulumi.get(__response__, 'exponential_backoff_min_wait'),
        git_branch=pulumi.get(__response__, 'git_branch'),
        git_repo=pulumi.get(__response__, 'git_repo'),
        id=pulumi.get(__response__, 'id'),
        insecure=pulumi.get(__response__, 'insecure'),
        insecure_plain_http=pulumi.get(__response__, 'insecure_plain_http'),
        labels=pulumi.get(__response__, 'labels'),
        name=pulumi.get(__response__, 'name'),
        resource_version=pulumi.get(__response__, 'resource_version'),
        secret_name=pulumi.get(__response__, 'secret_name'),
        secret_namespace=pulumi.get(__response__, 'secret_namespace'),
        service_account=pulumi.get(__response__, 'service_account'),
        service_account_namespace=pulumi.get(__response__, 'service_account_namespace'),
        url=pulumi.get(__response__, 'url')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ConfigMapV2Args', 'ConfigMapV2']

@pulumi.input_type
class ConfigMapV2Args:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[str],
                 data: pulumi.Input[Mapping[str, pulumi.Input[str]]],
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 immutable: Optional[pulumi.Input[bool]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ConfigMapV2 resource.
        :param pulumi.Input[str] cluster_id: The cluster id of the configMap V2 (string)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] data: The data of the configMap v2 (map)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations for the configMap v2 (map)
        :param pulumi.Input[bool] immutable: If set to true, any configMap update will remove and recreate the configMap. This is a beta field enabled by k8s `ImmutableEphemeralVolumes` feature gate. Default: `false` (bool)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Labels for the configMap v2 (map)
        :param pulumi.Input[str] name: The name of the configMap v2 (string)
        :param pulumi.Input[str] namespace: The namespaces of the configMap v2. Default: `default` (string)
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "data", data)
        if annotations is not None:
            pulumi.set(__self__, "annotations", annotations)
        if immutable is not None:
            pulumi.set(__self__, "immutable", immutable)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[str]:
        """
        The cluster id of the configMap V2 (string)
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def data(self) -> pulumi.Input[Mapping[str, pulumi.Input[str]]]:
        """
        The data of the configMap v2 (map)
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: pulumi.Input[Mapping[str, pulumi.Input[str]]]):
        pulumi.set(self, "data", value)

    @property
    @pulumi.getter
    def annotations(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Annotations for the configMap v2 (map)
        """
        return pulumi.get(self, "annotations")

    @annotations.setter
    def annotations(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "annotations", value)

    @property
    @pulumi.getter
    def immutable(self) -> Optional[pulumi.Input[bool]]:
        """
        If set to true, any configMap update will remove and recreate the configMap. This is a beta field enabled by k8s `ImmutableEphemeralVolumes` feature gate. Default: `false` (bool)
        """
        return pulumi.get(self, "immutable")

    @immutable.setter
    def immutable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "immutable", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Labels for the configMap v2 (map)
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the configMap v2 (string)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespaces of the configMap v2. Default: `default` (string)
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)


@pulumi.input_type
class _ConfigMapV2State:
    def __init__(__self__, *,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 data: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 immutable: Optional[pulumi.Input[bool]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 resource_version: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ConfigMapV2 resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations for the configMap v2 (map)
        :param pulumi.Input[str] cluster_id: The cluster id of the configMap V2 (string)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] data: The data of the configMap v2 (map)
        :param pulumi.Input[bool] immutable: If set to true, any configMap update will remove and recreate the configMap. This is a beta field enabled by k8s `ImmutableEphemeralVolumes` feature gate. Default: `false` (bool)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Labels for the configMap v2 (map)
        :param pulumi.Input[str] name: The name of the configMap v2 (string)
        :param pulumi.Input[str] namespace: The namespaces of the configMap v2. Default: `default` (string)
        :param pulumi.Input[str] resource_version: (Computed) The k8s resource version (string)
        """
        if annotations is not None:
            pulumi.set(__self__, "annotations", annotations)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if data is not None:
            pulumi.set(__self__, "data", data)
        if immutable is not None:
            pulumi.set(__self__, "immutable", immutable)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if resource_version is not None:
            pulumi.set(__self__, "resource_version", resource_version)

    @property
    @pulumi.getter
    def annotations(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Annotations for the configMap v2 (map)
        """
        return pulumi.get(self, "annotations")

    @annotations.setter
    def annotations(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "annotations", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster id of the configMap V2 (string)
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def data(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The data of the configMap v2 (map)
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "data", value)

    @property
    @pulumi.getter
    def immutable(self) -> Optional[pulumi.Input[bool]]:
        """
        If set to true, any configMap update will remove and recreate the configMap. This is a beta field enabled by k8s `ImmutableEphemeralVolumes` feature gate. Default: `false` (bool)
        """
        return pulumi.get(self, "immutable")

    @immutable.setter
    def immutable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "immutable", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Labels for the configMap v2 (map)
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the configMap v2 (string)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespaces of the configMap v2. Default: `default` (string)
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="resourceVersion")
    def resource_version(self) -> Optional[pulumi.Input[str]]:
        """
        (Computed) The k8s resource version (string)
        """
        return pulumi.get(self, "resource_version")

    @resource_version.setter
    def resource_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_version", value)


class ConfigMapV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 data: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 immutable: Optional[pulumi.Input[bool]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Rancher ConfigMap v2 resource. This can be used to create k8s configMaps for Rancher v2 environments and retrieve their information. ConfigMap v2 resource is available at Rancher v2.5.x and above.

        ## Import

        V2 configMaps can be imported using the Rancher cluster ID, ConfigMap V2 namespace and name.

        ```sh
        $ pulumi import rancher2:index/configMapV2:ConfigMapV2 foo &lt;CLUSTER_ID&gt;.&lt;SECRET_V2_NAMESPACE&gt;/&lt;SECRET_V2_NAME&gt;
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations for the configMap v2 (map)
        :param pulumi.Input[str] cluster_id: The cluster id of the configMap V2 (string)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] data: The data of the configMap v2 (map)
        :param pulumi.Input[bool] immutable: If set to true, any configMap update will remove and recreate the configMap. This is a beta field enabled by k8s `ImmutableEphemeralVolumes` feature gate. Default: `false` (bool)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Labels for the configMap v2 (map)
        :param pulumi.Input[str] name: The name of the configMap v2 (string)
        :param pulumi.Input[str] namespace: The namespaces of the configMap v2. Default: `default` (string)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConfigMapV2Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Rancher ConfigMap v2 resource. This can be used to create k8s configMaps for Rancher v2 environments and retrieve their information. ConfigMap v2 resource is available at Rancher v2.5.x and above.

        ## Import

        V2 configMaps can be imported using the Rancher cluster ID, ConfigMap V2 namespace and name.

        ```sh
        $ pulumi import rancher2:index/configMapV2:ConfigMapV2 foo &lt;CLUSTER_ID&gt;.&lt;SECRET_V2_NAMESPACE&gt;/&lt;SECRET_V2_NAME&gt;
        ```

        :param str resource_name: The name of the resource.
        :param ConfigMapV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConfigMapV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 data: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 immutable: Optional[pulumi.Input[bool]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConfigMapV2Args.__new__(ConfigMapV2Args)

            __props__.__dict__["annotations"] = annotations
            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            if data is None and not opts.urn:
                raise TypeError("Missing required property 'data'")
            __props__.__dict__["data"] = data
            __props__.__dict__["immutable"] = immutable
            __props__.__dict__["labels"] = labels
            __props__.__dict__["name"] = name
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["resource_version"] = None
        super(ConfigMapV2, __self__).__init__(
            'rancher2:index/configMapV2:ConfigMapV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            cluster_id: Optional[pulumi.Input[str]] = None,
            data: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            immutable: Optional[pulumi.Input[bool]] = None,
            labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            resource_version: Optional[pulumi.Input[str]] = None) -> 'ConfigMapV2':
        """
        Get an existing ConfigMapV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations for the configMap v2 (map)
        :param pulumi.Input[str] cluster_id: The cluster id of the configMap V2 (string)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] data: The data of the configMap v2 (map)
        :param pulumi.Input[bool] immutable: If set to true, any configMap update will remove and recreate the configMap. This is a beta field enabled by k8s `ImmutableEphemeralVolumes` feature gate. Default: `false` (bool)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Labels for the configMap v2 (map)
        :param pulumi.Input[str] name: The name of the configMap v2 (string)
        :param pulumi.Input[str] namespace: The namespaces of the configMap v2. Default: `default` (string)
        :param pulumi.Input[str] resource_version: (Computed) The k8s resource version (string)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConfigMapV2State.__new__(_ConfigMapV2State)

        __props__.__dict__["annotations"] = annotations
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["data"] = data
        __props__.__dict__["immutable"] = immutable
        __props__.__dict__["labels"] = labels
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["resource_version"] = resource_version
        return ConfigMapV2(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def annotations(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Annotations for the configMap v2 (map)
        """
        return pulumi.get(self, "annotations")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[str]:
        """
        The cluster id of the configMap V2 (string)
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def data(self) -> pulumi.Output[Mapping[str, str]]:
        """
        The data of the configMap v2 (map)
        """
        return pulumi.get(self, "data")

    @property
    @pulumi.getter
    def immutable(self) -> pulumi.Output[Optional[bool]]:
        """
        If set to true, any configMap update will remove and recreate the configMap. This is a beta field enabled by k8s `ImmutableEphemeralVolumes` feature gate. Default: `false` (bool)
        """
        return pulumi.get(self, "immutable")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Labels for the configMap v2 (map)
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the configMap v2 (string)
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespaces of the configMap v2. Default: `default` (string)
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="resourceVersion")
    def resource_version(self) -> pulumi.Output[str]:
        """
        (Computed) The k8s resource version (string)
        """
        return pulumi.get(self, "resource_version")

